@@ -451,7 +451,7 @@ static int fill_client_infos(prelude_client_t *client, const char *program)
 
         idmef_process_set_pid(process, getpid());
 
-        if ( ! program )
+        if ( ! program || ! *program )
                 return 0;
 
         name = path = NULL;
@@ -1243,6 +1243,13 @@ int prelude_client_init(prelude_client_t *client)
         prelude_string_t *err;
         prelude_option_warning_t old_warnings;
 
+        /*
+         * Calling two time init() would result in error in
+         * fill_client_infos(), due to idmef_analyzer_t object reuse.
+         */
+        if ( client->status != CLIENT_STATUS_NEED_INIT )
+                return 0;
+
         prelude_return_val_if_fail(client, prelude_error(PRELUDE_ERROR_ASSERTION));
 
         prelude_option_set_warnings(0, &old_warnings);
@@ -1764,6 +1771,7 @@ prelude_client_profile_t *prelude_client_get_profile(prelude_client_t *client)
 
 
 
+#ifndef PRELUDE_DISABLE_DEPRECATED
 /**
  * prelude_client_is_setup_needed:
  * @error: Error returned by prelude_client_start().
@@ -1785,7 +1793,6 @@ prelude_bool_t prelude_client_is_setup_needed(int error)
 }
 
 
-
 const char *prelude_client_get_setup_error(prelude_client_t *client)
 {
         int ret;
@@ -1833,6 +1840,7 @@ const char *prelude_client_get_setup_error(prelude_client_t *client)
 
         return _prelude_thread_get_error();
 }
+#endif
 
 
 
