@@ -30,15 +30,12 @@
 #include <unistd.h>
 #include <errno.h>
 #include <netinet/in.h>
-#include <arpa/inet.h>
+#include <poll.h>
+#include <sys/ioctl.h>
 #include <gnutls/gnutls.h>
 
 #include "prelude-inttypes.h"
 
-#ifdef HAVE_SYS_IOCTL_H
-# include <sys/ioctl.h>
-#endif
-
 #ifdef HAVE_SYS_FILIO_H
 # include <sys/filio.h>
 #endif
@@ -59,10 +56,6 @@
 # define MIN(x, y) ((x) < (y) ? (x) : (y))
 #endif
 
-#if (defined _WIN32 || defined __WIN32__) && !defined __CYGWIN__
-# define ioctl ioctlsocket
-#endif
-
 struct prelude_io {
 
         int fd;
