@@ -24,15 +24,18 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <errno.h>
 
-#include <gcrypt.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
 
+#include "glthread/lock.h"
+
 #define PRELUDE_ERROR_SOURCE_DEFAULT PRELUDE_ERROR_SOURCE_CONNECTION
 #include "prelude-error.h"
 
@@ -41,15 +44,11 @@
 #include "prelude-client.h"
 #include "prelude-message-id.h"
 #include "prelude-extract.h"
-#include "prelude-thread.h"
 
 #include "tls-util.h"
 #include "tls-auth.h"
 
 
-GCRY_THREAD_OPTION_PTHREAD_IMPL;
-
-
 
 #ifdef HAVE_GNUTLS_STRING_PRIORITY
 
@@ -58,7 +57,7 @@ static gnutls_priority_t tls_priority;
 #endif
 
 static prelude_bool_t priority_set = FALSE;
-static prelude_bool_t gnutls_initialized = FALSE;
+
 
 
 static int read_auth_result(prelude_io_t *fd)
@@ -214,35 +213,11 @@ static void set_default_priority(gnutls_session session)
 }
 
 
-
-static int init_gnutls(void)
-{
-        int ret;
-
-        if ( gnutls_initialized )
-                return 0;
-
-        ret = gnutls_global_init();
-        if ( ret < 0 )
-                return prelude_error_verbose_make(PRELUDE_ERROR_SOURCE_CLIENT, PRELUDE_ERROR_TLS,
-                                                  "TLS initialization failed: %s", gnutls_strerror(ret));
-
-        gnutls_initialized = TRUE;
-
-        return 0;
-}
-
-
 int tls_auth_init_priority(const char *tlsopts)
 {
-        int ret;
-
-        ret = init_gnutls();
-        if ( ret < 0 )
-                return ret;
-
 #ifdef HAVE_GNUTLS_STRING_PRIORITY
         {
+                int ret;
                 const char *errptr;
 
                 ret = gnutls_priority_init(&tls_priority, (tlsopts) ? tlsopts : "NORMAL", &errptr);
@@ -346,13 +321,6 @@ int tls_auth_init(prelude_client_profile_t *cp, gnutls_certificate_credentials *
 
         *cred = NULL;
 
-        if ( _prelude_thread_in_use() )
-                gcry_control(GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
-
-        ret = init_gnutls();
-        if ( ret < 0 )
-                return ret;
-
         prelude_client_profile_get_tls_key_filename(cp, keyfile, sizeof(keyfile));
         ret = access(keyfile, F_OK);
         if ( ret < 0 )
@@ -420,9 +388,4 @@ void tls_auth_deinit(void)
                 priority_set = FALSE;
         }
 #endif
-
-        if ( gnutls_initialized ) {
-                gnutls_global_deinit();
-                gnutls_initialized = FALSE;
-        }
 }
